@@ -18,7 +18,7 @@ class HELML:
     CUSTOM_VALUE_ENCODER = None
     CUSTOM_VALUE_DECODER = None
     
-    ENABLE_SPC_IDENT = True # For encode: add space-indentation at begin of string
+    ENABLE_SPC_IDENT = 1 # For encode: add space-indentation at begin of string
     ENABLE_BONES = True # For encode: enable use "next"-keys like :--:
     ENABLE_KEY_UPLINES = True # For encode: add empty line before create-array-keys
     ENABLE_HASHSYMBOLS = True # For encode: adding # after nested-blocks
@@ -26,18 +26,19 @@ class HELML:
     @staticmethod
     def encode(
         arr: Union[dict, list, tuple, set],
-        url_mode: bool = False
+        one_line_mode: int = 0
     ) -> str:
         """
         Encode array to HELML string.
-        
+
         :param arr: Input data structure (list, dict, or tuple) to be encoded.
-        :param url_mode: A boolean indicating if the URL mode should be used.
+        :param one_line_mode: The encoding mode to use (0-multi-line, 1-URL-mode, 2-LINE-mode)
         :return: Encoded HELML string.
         """
         results_arr = []
 
-        str_imp = "~" if url_mode else "\n"
+        str_imp = "~" if one_line_mode else "\n"
+        url_mode = one_line_mode == 1
         lvl_ch = "." if url_mode else ":"
         spc_ch = "_" if url_mode else " "
 
@@ -45,8 +46,13 @@ class HELML:
         
         HELML._encode(arr, results_arr, 0, lvl_ch, spc_ch, is_list)
 
-        if url_mode and len(results_arr) == 1:
+        if url_mode:
             results_arr.append('')
+        elif one_line_mode:
+            # Remove whitespace from beginning and end of each string
+            results_arr = [s.strip() for s in results_arr]
+            # Remove empty strings and comments that start with '#'
+            results_arr = [s for s in results_arr if s and not s.startswith('#')]
 
         return str_imp.join(results_arr)
     
@@ -91,7 +97,7 @@ class HELML:
 
              # add space-ident to the left of the key (if need)
             if HELML.ENABLE_SPC_IDENT and spc_ch == ' ':
-                ident = spc_ch * level + ident
+                ident = spc_ch * (level * HELML.ENABLE_SPC_IDENT) + ident
 
             is_arr = isinstance(value, (list, tuple, set))
 
@@ -147,7 +153,7 @@ class HELML:
         # Explode src_rows to lines
         for exploder_ch in ["\n", "\r", "~"]:
             if exploder_ch in src_rows:
-                if "~" == exploder_ch:
+                if "~" == exploder_ch and src_rows[-1] == "~":
                     lvl_ch = "."
                     spc_ch = "_"
                 break
